@@ -21,6 +21,7 @@ customer_id = '8306215642' #google ads customer id
 start_date='2022-01-01'
 end_date='2022-01-02'
 
+cost_threshold = 0  # get cost >= cost_threshold
 conversion_threshold = 1 #  get conversion >= conversion_threshold
 first_threshold = 0.8 # similarity threshold for keyword similarity
 second_threshold = 0.8 # similarity threshold for description similarity
@@ -59,7 +60,7 @@ df_search_term_report_negative = df_search_term_report.loc[df_search_term_report
 df_exclude_from_negative = get_shared_set_keywords(googleads_client,customer_id)
 exclude_keywords = df_exclude_from_negative['shared_criterion_keyword_text'].unique().tolist()
 df_search_term_report_negative = df_search_term_report_negative.loc[~df_search_term_report_negative['stv_search_term'].isin(exclude_keywords)]
-df_search_term_report_negative = df_search_term_report_negative.loc[df_search_term_report_negative['metrics_cost']>0]
+df_search_term_report_negative = df_search_term_report_negative.loc[df_search_term_report_negative['metrics_cost']>=cost_threshold * 1000000]
 df_search_term_report_negative = df_search_term_report_negative.drop_duplicates("stv_search_term")
 # df_search_term_report_negative.to_csv(save_path+'/df_search_term_report_negative.csv',index=False)
 
@@ -83,6 +84,9 @@ model = SentenceTransformer(similarity_model_path)
 
 def calculate_similarity(df,model,first_threshold,second_threshold,third_threshold,negative=False):
     print("Calculating First similarity keywords")
+    df['Keywords'] = df['Keywords'].apply(lambda x:str(x))
+    df['Keywords2'] = df['Keywords2'].apply(lambda x:str(x))
+
     keywords1 = df['Keywords'].tolist()
     keywords2 = df['Keywords2'].tolist()
     df['first_similarity'] = get_similarity_api(model,keywords1,keywords2)
@@ -138,6 +142,7 @@ def calculate_similarity(df,model,first_threshold,second_threshold,third_thresho
         return "" if len(keyword) == 0 else ' '.join(keyword)
 
     df['Keywords3'] = df.apply(remove_word,axis=1)
+    df['Keywords3'] = df['Keywords3'].apply(lambda x:str(x))
 
     print("Performing third similarity")
     keywords1 = df['Keywords2'].tolist()
@@ -336,4 +341,4 @@ else:
     print("No keywords to add in negative list")
 
 info_df = pd.DataFrame.from_dict(info_dict)
-info_df.to_csv(save_path+f'/history/{datetime.now().strftime("%m-%d-%Y %H-%M-%S")}.csv', index=False)
\ No newline at end of file
+info_df.to_csv(save_path+f'/history/{datetime.now().strftime("%m-%d-%Y %H-%M-%S")}.csv', index=False)
